import java.util.regex.Pattern;

public class EMail {
	/**
	 * Checks if the email is in a valid format
	 * @param email The email address being checked
	 * @return <code>true</code> if the email is correctly formatted, otherwise <code>false</code>
	 */
	public static boolean validate(String email) {
		// Set up regex for email format
		String emailRegex = "[^@ \\t\\r\\n]+@[^@ \\t\\r\\n]+\\.[^@ \\t\\r\\n]+";
		Pattern pattern = Pattern.compile(emailRegex);
		
		// Checks and returns if the email matches the regex pattern
		return pattern.matcher(email).matches();
	}

	/**
	 * Retrieves the domain part of the email address
	 * @param email A valid email address
	 * @return The domain of the email address from the parameter
	 */
	public static String getDomain(String email) {
		// Checks that the email address is valid, otherwise throw exception
		if (!validate(email)) {
			throw new IllegalArgumentException("The email address provided is not valid");
		}
		
		// Returns the domain of the email address
		return email.split("@")[1];
	}
}
